@@ -7,13 +7,19 @@
 ;;;; Programmer:    Kevin M. Rosenberg
 ;;;; Date Started:  Sep 2003
 ;;;;
-;;;; $Id: rss.asd 7061 2003-09-07 06:34:45Z kevin $
+;;;; $Id$
 ;;;; *************************************************************************
 
 (in-package cl-user)
 (defpackage rss
   (:use #:cl #:kmrcl)
   (:export
-   #:show-sites
-   ))
+   #:rss-channel #:rss-item #:rss-image
+   #:show-sites #:rss-site
+   #:parse-rss-file #:parse-rss-stream
+
+   ;; Accessors to class slots
+   #:title #:link #:description #:language #:pub-date #:image #:items
+   #:url #:width #:height #:last-build-date))
+
 
